@@ -10,8 +10,8 @@
 #include <QDebug>
 #include <QTest>
 
-#include <kmime/kmime_content.h>
-#include <kmime/kmime_headers.h>
+#include <KMime/Content>
+#include <KMime/Headers>
 using namespace KMime;
 
 #include <MessageComposer/AttachmentJob>
@@ -19,7 +19,6 @@ using namespace KMime;
 #include <MessageComposer/GlobalPart>
 using namespace MessageComposer;
 
-//#include "messagecore/attachmentfromfolderjob.h"
 #include <MessageCore/AttachmentPart>
 using namespace MessageCore;
 
@@ -102,3 +101,5 @@ void AttachmentJobTest::testTextCharsetAutodetect()
 }
 
 #endif
+
+#include "moc_attachmentjobtest.cpp"
