@@ -423,7 +423,7 @@ void CryptoComposerTest::testBCCEncrypt()
     std::vector<GpgME::Key> skeys;
     skeys.push_back(keys[2]);
 
-    QVector<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
+    QList<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key>>(primRecipients, pkeys));
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key>>(secondRecipients, skeys));
 
@@ -780,7 +780,7 @@ void CryptoComposerTest::testAutocryptGossip()
             eKeys.push_back(keys[0]);
             eKeys.push_back(keys[1]);
 
-            QVector<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
+            QList<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
             encKeys.append({recipients, eKeys});
 
             composer.setEncryptionKeys(encKeys);
@@ -846,7 +846,7 @@ void CryptoComposerTest::fillComposerCryptoData(Composer *composer)
     QStringList recipients;
     recipients << QString::fromLocal8Bit("you@you.you");
 
-    QVector<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
+    QList<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key>>(recipients, keys));
 
     composer->setEncryptionKeys(encKeys);
@@ -866,7 +866,7 @@ void CryptoComposerTest::runSMIMETest(bool sign, bool enc, bool opaque)
     std::vector<GpgME::Key> keys = MessageComposer::Test::getKeys(true);
     QStringList recipients;
     recipients << QString::fromLocal8Bit("you@you.you");
-    QVector<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
+    QList<QPair<QStringList, std::vector<GpgME::Key>>> encKeys;
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key>>(recipients, keys));
     composer->setEncryptionKeys(encKeys);
     composer->setSigningKeys(keys);
@@ -896,3 +896,5 @@ void CryptoComposerTest::runSMIMETest(bool sign, bool enc, bool opaque)
         QCOMPARE(message->to()->asUnicodeString(), QString::fromLocal8Bit("you@you.you"));
     }
 }
+
+#include "moc_cryptocomposertest.cpp"
