@@ -38,7 +38,7 @@ public:
     ~AttachmentModelPrivate();
 
     AttachmentPart::List parts;
-    QVector<QTemporaryDir *> tempDirs;
+    QList<QTemporaryDir *> tempDirs;
     AttachmentModel *const q;
     bool modified = false;
     bool encryptEnabled = false;
@@ -491,3 +491,5 @@ int AttachmentModel::columnCount(const QModelIndex &parent) const
     Q_UNUSED(parent)
     return LastColumn;
 }
+
+#include "moc_attachmentmodel.cpp"
