@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -48,7 +48,7 @@ private Q_SLOTS:
     void slotCreateNewTodo(KJob *job);
 
 private:
-    void writeFollowupReminderInfo();
+    MESSAGECOMPOSER_NO_EXPORT void writeFollowupReminderInfo();
 
     std::unique_ptr<FollowupReminderCreateJobPrivate> const d;
 };
