@@ -7,7 +7,6 @@
  *******************************************************************************/
 #include "core/sortorder.h"
 
-#include "messagelistutil.h"
 #include "messagelistutil_p.h"
 
 #include <KLocalizedString>
@@ -58,9 +57,9 @@ void SortOrder::setMessageSortDirection(SortOrder::SortDirection messageSortDire
     mMessageSortDirection = messageSortDirection;
 }
 
-QVector<QPair<QString, int>> SortOrder::enumerateMessageSortingOptions(Aggregation::Threading t)
+QList<QPair<QString, int>> SortOrder::enumerateMessageSortingOptions(Aggregation::Threading t)
 {
-    QVector<QPair<QString, int>> ret;
+    QList<QPair<QString, int>> ret;
     ret.append({i18n("None (Storage Order)"), SortOrder::NoMessageSorting});
     ret.append({i18n("By Date/Time"), SortOrder::SortMessagesByDateTime});
     if (t != Aggregation::NoThreading) {
@@ -78,9 +77,9 @@ QVector<QPair<QString, int>> SortOrder::enumerateMessageSortingOptions(Aggregati
     return ret;
 }
 
-QVector<QPair<QString, int>> SortOrder::enumerateMessageSortDirectionOptions(MessageSorting ms)
+QList<QPair<QString, int>> SortOrder::enumerateMessageSortDirectionOptions(MessageSorting ms)
 {
-    QVector<QPair<QString, int>> ret;
+    QList<QPair<QString, int>> ret;
     if (ms == SortOrder::NoMessageSorting) {
         return ret;
     }
@@ -96,9 +95,9 @@ QVector<QPair<QString, int>> SortOrder::enumerateMessageSortDirectionOptions(Mes
     return ret;
 }
 
-QVector<QPair<QString, int>> SortOrder::enumerateGroupSortingOptions(Aggregation::Grouping g)
+QList<QPair<QString, int>> SortOrder::enumerateGroupSortingOptions(Aggregation::Grouping g)
 {
-    QVector<QPair<QString, int>> ret;
+    QList<QPair<QString, int>> ret;
     if (g == Aggregation::NoGrouping) {
         return ret;
     }
@@ -120,9 +119,9 @@ QVector<QPair<QString, int>> SortOrder::enumerateGroupSortingOptions(Aggregation
     return ret;
 }
 
-QVector<QPair<QString, int>> SortOrder::enumerateGroupSortDirectionOptions(Aggregation::Grouping g, GroupSorting gs)
+QList<QPair<QString, int>> SortOrder::enumerateGroupSortDirectionOptions(Aggregation::Grouping g, GroupSorting gs)
 {
-    QVector<QPair<QString, int>> ret;
+    QList<QPair<QString, int>> ret;
     if (g == Aggregation::NoGrouping || gs == SortOrder::NoGroupSorting) {
         return ret;
     }
@@ -137,7 +136,7 @@ QVector<QPair<QString, int>> SortOrder::enumerateGroupSortDirectionOptions(Aggre
     return ret;
 }
 
-using OptionList = QVector<QPair<QString, int>>;
+using OptionList = QList<QPair<QString, int>>;
 static bool optionListHasOption(const OptionList &optionList, int optionValue, int defaultOptionValue)
 {
     for (const auto &pair : optionList) {
