@@ -372,7 +372,7 @@ void View::applyThemeColumns()
     // all saved then the total hint is equal to the total saved width.
 
     int totalVisibleWidthHint = 0;
-    QVector<int> lColumnSizeHints;
+    QList<int> lColumnSizeHints;
     for (const auto col : std::as_const(columns)) {
         if (col->currentlyVisible() || (idx == 0)) {
             // qCDebug(MESSAGELIST_LOG) << "Column " << idx << " will be visible";
@@ -397,7 +397,7 @@ void View::applyThemeColumns()
     // Now compute somewhat "proportional" widths.
     idx = 0;
 
-    QVector<double> lColumnWidths;
+    QList<double> lColumnWidths;
     lColumnWidths.reserve(columns.count());
     int totalVisibleWidth = 0;
     for (const auto col : std::as_const(columns)) {
@@ -726,11 +726,6 @@ int View::sizeHintForColumn(int logicalColumnIndex) const
     return w;
 }
 
-void View::showEvent(QShowEvent *e)
-{
-    QTreeView::showEvent(e);
-}
-
 void View::slotHeaderContextMenuRequested(const QPoint &pnt)
 {
     if (!d->mTheme) {
@@ -891,9 +886,9 @@ bool View::selectionEmpty() const
     return selectionModel()->selectedRows().isEmpty();
 }
 
-QVector<MessageItem *> View::selectionAsMessageItemList(bool includeCollapsedChildren) const
+QList<MessageItem *> View::selectionAsMessageItemList(bool includeCollapsedChildren) const
 {
-    QVector<MessageItem *> selectedMessages;
+    QList<MessageItem *> selectedMessages;
 
     QModelIndexList lSelected = selectionModel()->selectedRows();
     if (lSelected.isEmpty()) {
@@ -934,9 +929,9 @@ QVector<MessageItem *> View::selectionAsMessageItemList(bool includeCollapsedChi
     return selectedMessages;
 }
 
-QVector<MessageItem *> View::currentThreadAsMessageItemList() const
+QList<MessageItem *> View::currentThreadAsMessageItemList() const
 {
-    QVector<MessageItem *> currentThread;
+    QList<MessageItem *> currentThread;
 
     MessageItem *msg = currentMessageItem();
     if (!msg) {
@@ -1087,7 +1082,7 @@ void View::setAllGroupsExpanded(bool expand)
     }
 }
 
-void View::selectMessageItems(const QVector<MessageItem *> &list)
+void View::selectMessageItems(const QList<MessageItem *> &list)
 {
     QItemSelection selection;
     for (const auto mi : list) {
@@ -1634,7 +1629,7 @@ void View::modelFinishedLoading()
     // nothing here for now :)
 }
 
-MessageItemSetReference View::createPersistentSet(const QVector<MessageItem *> &items)
+MessageItemSetReference View::createPersistentSet(const QList<MessageItem *> &items)
 {
     return d->mModel->createPersistentSet(items);
 }
@@ -2128,7 +2123,7 @@ void View::changeEvent(QEvent *e)
     switch (e->type()) {
     case QEvent::FontChange:
         d->mDelegate->generalFontChanged();
-        Q_FALLTHROUGH();
+        [[fallthrough]];
     case QEvent::PaletteChange:
     case QEvent::StyleChange:
     case QEvent::LayoutDirectionChange:
@@ -2524,7 +2519,7 @@ void View::focusQuickSearch(const QString &selectedText)
     d->mWidget->focusQuickSearch(selectedText);
 }
 
-QVector<Akonadi::MessageStatus> View::currentFilterStatus() const
+QList<Akonadi::MessageStatus> View::currentFilterStatus() const
 {
     return d->mWidget->currentFilterStatus();
 }
@@ -2767,13 +2762,6 @@ void View::ViewPrivate::tapTriggered(QTapGesture *tap)
         }
 
         // simulate a mousePressEvent, to allow QTreeView to select the items
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QMouseEvent fakeMousePress(QEvent::MouseButtonPress,
-                                   tap->position(),
-                                   mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
-                                   mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
-                                   Qt::NoModifier);
-#else
         QMouseEvent fakeMousePress(QEvent::MouseButtonPress,
                                    tap->position(),
                                    q->viewport()->mapToGlobal(tap->position()),
@@ -2781,7 +2769,6 @@ void View::ViewPrivate::tapTriggered(QTapGesture *tap)
                                    mTapAndHoldActive ? Qt::RightButton : Qt::LeftButton,
                                    Qt::NoModifier);
 
-#endif
         onPressed(&fakeMousePress);
         mTapAndHoldActive = false;
     }
@@ -2819,11 +2806,7 @@ void View::ViewPrivate::tapAndHoldTriggered(QTapAndHoldGesture *tap)
 
         // simulate a mousePressEvent, to allow QTreeView to select the items
         const QPoint tapViewportPos(q->viewport()->mapFromGlobal(tap->position().toPoint()));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tapViewportPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
-#else
         QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tapViewportPos, tapViewportPos, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
-#endif
         onPressed(&fakeMousePress);
 
         const QPoint tapIndicatorSize(80, 80); // size for the tapAndHold indicator
@@ -2848,16 +2831,12 @@ void View::ViewPrivate::twoFingerTapTriggered(KTwoFingerTap *tap)
         }
 
         // simulate a mousePressEvent with Qt::ControlModifier, to allow QTreeView to select the items
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QMouseEvent fakeMousePress(QEvent::MouseButtonPress, tap->pos(), Qt::LeftButton, Qt::LeftButton, Qt::ControlModifier);
-#else
         QMouseEvent fakeMousePress(QEvent::MouseButtonPress,
                                    tap->pos(),
                                    q->viewport()->mapToGlobal(tap->pos()),
                                    Qt::LeftButton,
                                    Qt::LeftButton,
                                    Qt::ControlModifier);
-#endif
         onPressed(&fakeMousePress);
     }
 }
