@@ -26,7 +26,7 @@ namespace ComboBoxUtils
  * Each option descriptor contains a description string and a distinct integer (possibly enum)
  * identifier value.
  */
-void fillIntegerOptionCombo(QComboBox *combo, const QVector<QPair<QString, int>> &optionDescriptors);
+void fillIntegerOptionCombo(QComboBox *combo, const QList<QPair<QString, int>> &optionDescriptors);
 
 /**
  * Returns the identifier of the currently selected option in the specified combo.
@@ -42,4 +42,3 @@ void setIntegerOptionComboValue(QComboBox *combo, int value);
 } // namespace ComboBoxUtils
 } // namespace Utils
 } // namespace MessageList
-
