@@ -23,7 +23,7 @@ using namespace MessageViewer;
 class TestBodyPartURLHandler : public Interface::BodyPartURLHandler
 {
 public:
-    Q_REQUIRED_RESULT QString name() const override
+    [[nodiscard]] QString name() const override
     {
         return QStringLiteral("TestBodyPartURLHandler");
     }
@@ -121,3 +121,5 @@ void BodyPartUrlHandlerManagerTest::testHandleClick()
 }
 
 QTEST_MAIN(BodyPartUrlHandlerManagerTest)
+
+#include "moc_urlhandlermanagertest.cpp"
