@@ -1,27 +1,13 @@
-/* Copyright 2009 Thomas McGuire <mcguire@kde.org>
+/* SPDX-FileCopyrightText: 2009 Thomas McGuire <mcguire@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #include "objecttreeparsertest.h"
-#include "util.h"
 #include "setupenv.h"
+#include "util.h"
 
-#include <MimeTreeParser/ObjectTreeParser>
 #include <MessageViewer/BufferedHtmlWriter>
+#include <MimeTreeParser/ObjectTreeParser>
 
 #include <QTest>
 
@@ -58,6 +44,7 @@ void ObjectTreeParserTester::test_HTMLOnlyText()
     QVERIFY(otp.htmlContent().contains(QLatin1String("<b>SOME</b> HTML text.")));
     QVERIFY(testWriter.data().contains("This is an HTML message. For security reasons, only the raw HTML code is shown."));
     QVERIFY(testWriter.data().contains("SOME* HTML text. <br>"));
+    msg.clear();
 }
 
 void ObjectTreeParserTester::test_HTMLExternal()
@@ -82,7 +69,8 @@ void ObjectTreeParserTester::test_HTMLExternal()
         QVERIFY(otp.plainTextContent().isEmpty());
         QVERIFY(otp.htmlContent().contains(QLatin1String("<b>SOME</b> HTML text.")));
         QVERIFY(testWriter.data().contains("<b>SOME</b> HTML text."));
-        QVERIFY(testWriter.data().contains("This HTML message may contain external references to images etc. For security/privacy reasons external references are not loaded."));
+        QVERIFY(testWriter.data().contains(
+            "This HTML message may contain external references to images etc. For security/privacy reasons external references are not loaded."));
     }
     {
         BufferedHtmlWriter testWriter;
@@ -99,8 +87,10 @@ void ObjectTreeParserTester::test_HTMLExternal()
 
         QVERIFY(otp.htmlContent().contains(QLatin1String("<b>SOME</b> HTML text.")));
         QVERIFY(testWriter.data().contains("<b>SOME</b> HTML text."));
-        QVERIFY(!testWriter.data().contains("This HTML message may contain external references to images etc. For security/privacy reasons external references are not loaded."));
+        QVERIFY(!testWriter.data().contains(
+            "This HTML message may contain external references to images etc. For security/privacy reasons external references are not loaded."));
     }
+    msg.clear();
 }
 
 void ObjectTreeParserTester::test_Alternative()
@@ -121,8 +111,8 @@ void ObjectTreeParserTester::test_Alternative()
         testWriter.end();
 
         QVERIFY(otp.htmlContent().isEmpty());
-        QVERIFY(otp.plainTextContent().contains(QLatin1String(
-                                                    "If you can see this text it means that your email client couldn't display our newsletter properly.")));
+        QVERIFY(otp.plainTextContent().contains(
+            QLatin1String("If you can see this text it means that your email client couldn't display our newsletter properly.")));
         QVERIFY(testWriter.data().contains("If you can see this text it means that your email client couldn't display our newsletter properly."));
     }
 
@@ -139,13 +129,13 @@ void ObjectTreeParserTester::test_Alternative()
         emptySource.render(otp.parsedPart(), false);
         testWriter.end();
 
-        QVERIFY(otp.plainTextContent().contains(QLatin1String(
-                                                    "If you can see this text it means that your email client couldn't display our newsletter properly.")));
-        QVERIFY(otp.htmlContent().contains(QLatin1String(
-                                               "Some <span style=\" font-weight:600;\">HTML</span> text</p>")));
+        QVERIFY(otp.plainTextContent().contains(
+            QLatin1String("If you can see this text it means that your email client couldn't display our newsletter properly.")));
+        QVERIFY(otp.htmlContent().contains(QLatin1String("Some <span style=\" font-weight:600;\">HTML</span> text</p>")));
         QVERIFY(testWriter.data().contains("Some <span style=\" font-weight:600;\">HTML</span> text</p>"));
     }
 
+    msg.clear();
     msg = Test::readAndParseMail(QStringLiteral("alternative-notext.mbox"));
     QCOMPARE(msg->contents().size(), 1);
     {
@@ -181,8 +171,10 @@ void ObjectTreeParserTester::test_Alternative()
         testWriter.end();
 
         QVERIFY(otp.plainTextContent().isEmpty());
-        QVERIFY(otp.htmlContent().contains(QLatin1String(
-                                               "Some <span style=\" font-weight:600;\">HTML</span> text</p>")));
+        QVERIFY(otp.htmlContent().contains(QLatin1String("Some <span style=\" font-weight:600;\">HTML</span> text</p>")));
         QVERIFY(testWriter.data().contains("Some <span style=\" font-weight:600;\">HTML</span> text</p>"));
     }
+    msg.clear();
 }
+
+#include "moc_objecttreeparsertest.cpp"
