@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -22,6 +22,9 @@ public:
     ~ScamDetectionWhiteListSettingsManager() override;
     static ScamDetectionWhiteListSettingsManager *self();
 
+    [[nodiscard]] QList<ScamDetectionInfo> scamDetectionInfoList() const;
+    void setScamDetectionInfoList(const QList<ScamDetectionInfo> &newScamDetectionInfoList);
+
 private:
     MESSAGEVIEWER_NO_EXPORT void loadSettings();
     MESSAGEVIEWER_NO_EXPORT void writeSettings();
